@@ -1,12 +1,12 @@
 #' Call R CMD 'command' with build tools active
 #'
-#' This is a wrapper around [callr::rcmd_safe()] that checks
+#' This is a wrapper around `callr::rcmd_safe()` that checks
 #' that you have build tools available, and on Windows, automatically sets
 #' the path to include Rtools.
 #'
 #' @param ... Parameters passed on to `rcmd_safe`.
 #' @param env Additional environment variables to set. The defaults from
-#'   [callr::rcmd_safe_env()] are always set.
+#'   `callr::rcmd_safe_env()` are always set.
 #' @inheritParams with_build_tools
 #' @inheritParams build
 #' @export
@@ -23,11 +23,22 @@ rcmd_build_tools <- function(..., env = character(), required = TRUE, quiet = FA
 
   warn_for_potential_errors()
 
-  res <- with_build_tools(
-    callr::rcmd_safe(..., env = env, spinner = FALSE, show = FALSE,
-      echo = FALSE, block_callback = block_callback(quiet), stderr = "2>&1"),
-    required = required
-  )
+  callback <- if (cli::is_dynamic_tty()) {
+    block_callback(quiet)
+  } else {
+    simple_callback(quiet)
+  }
+
+  res <- with_build_tools({
+    withCallingHandlers(
+      callr::rcmd_safe(..., env = env, spinner = FALSE, show = FALSE,
+        echo = FALSE, block_callback = callback, stderr = "2>&1"),
+      error = function(e) {
+        if (!quiet) e$echo <- TRUE
+        asNamespace("callr")$err$throw(e)
+      }
+    )
+  }, required = required)
 
   msg_for_long_paths(res)
 
